/**
 *  Bitloops Language CLI
 *  Copyright (C) 2022 Bitloops S.A.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 *  For further information you can contact legal(at)bitloops.com.
 */
import { readFromFile } from '../helpers/fileOperations.js';
import { BitloopsIntermediateSetupASTParser, BitloopsSetupParser, BitloopsSetupParserError, } from '@bitloops/bl-transpiler';
const generateSetupDataModel = (sourceDirPath) => {
    // TODO handle possibly multiple setup files
    const content = readFromFile(`${sourceDirPath}/setup.bl`);
    // const setupData = main(content);
    const parser = new BitloopsSetupParser();
    const initialModelOutput = parser.parse(content);
    const intermediateParser = new BitloopsIntermediateSetupASTParser();
    if (!(initialModelOutput instanceof BitloopsSetupParserError)) {
        const result = intermediateParser.parse(initialModelOutput);
        if (result instanceof BitloopsSetupParserError) {
            console.log(result);
            throw new Error('Error parsing setup file');
        }
        return result;
    }
    throw new Error('Error parsing setup file');
};
export { generateSetupDataModel };
//# sourceMappingURL=generateSetupModel.js.map